@@ -11,7 +11,7 @@
 /*                                                                              */
 /********************************************************************************/
 
-#include <link-grammar/link-includes.h>
+#include <link-grammar/api.h>
 
 /***************************************************************
 *
@@ -417,6 +417,48 @@ Dictionary dictionary_create(char * dict_name, char * pp_name, char * cons_name,
     return internal_dictionary_create(dict_name, pp_name, cons_name, affix_name, NULL);
 }
 
+Dictionary dictionary_create_lang(char * lang)
+{
+  Dictionary dictionary;
+  char * dict_name;
+  char * pp_name;
+  char * cons_name;
+  char * affix_name;  
+
+  if(!lang && *lang)
+    return NULL;
+
+  dict_name = join_path(lang, "4.0.dict");
+  pp_name = join_path(lang, "4.0.knowledge");
+  cons_name = join_path(lang, "4.0.constituent-knowledge");
+  affix_name = join_path(lang, "4.0.affix");
+
+  dictionary = dictionary_create(dict_name, pp_name, cons_name, affix_name);
+
+  free(affix_name);
+  free(cons_name);
+  free(pp_name);
+  free(dict_name);
+
+  return dictionary;
+}
+
+Dictionary dictionary_create_default_lang(void)
+{
+  Dictionary dictionary;
+  char * locale;
+
+  locale = get_default_locale();
+  if(!locale && *locale)
+    return NULL;
+
+  dictionary = dictionary_create_lang(locale);
+
+  free(locale);
+
+  return dictionary;
+}
+
 /* obsolete *DS*
 void dictionary_open_affix_file(Dictionary dict, char * affix_file) {
     dict->affix_table = dictionary_create(affix_file, NULL);
